[![GPL3 License](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![PyPI packaged release](https://badge.fury.io/py/mlx.traceability.svg)](https://badge.fury.io/py/mlx.traceability)
[![Build status](https://github.com/melexis/sphinx-traceability-extension/actions/workflows/python-package.yml/badge.svg?branch=master)](https://github.com/melexis/sphinx-traceability-extension/actions/workflows/python-package.yml)
[![Documentation](https://img.shields.io/badge/Documentation-published-brightgreen.svg)](https://melexis.github.io/sphinx-traceability-extension/)
[![Code Coverage](https://codecov.io/gh/melexis/sphinx-traceability-extension/coverage.svg)](https://codecov.io/gh/melexis/sphinx-traceability-extension)
[![Code Climate Status](https://codeclimate.com/github/melexis/sphinx-traceability-extension/badges/gpa.svg)](https://codeclimate.com/github/melexis/sphinx-traceability-extension)
[![Requirements Status](https://requires.io/github/melexis/sphinx-traceability-extension/requirements.svg?branch=master)](https://requires.io/github/melexis/sphinx-traceability-extension/requirements/?branch=master)
[![Contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/melexis/sphinx-traceability-extension/issues)


# Sphinx Traceability plugin

Sphinx plugin that allows defining documentation items and relations between those items. Can be used
as a requirements management tool for e.g. ISO26262 projects.

## Contents

- [Goal](https://melexis.github.io/sphinx-traceability-extension/goal.html)
- [Installation](https://melexis.github.io/sphinx-traceability-extension/installation.html)
- [Configuration](https://melexis.github.io/sphinx-traceability-extension/configuration.html)
- [Usage](https://melexis.github.io/sphinx-traceability-extension/usage.html)
- [Contributing](https://melexis.github.io/sphinx-traceability-extension/contributing.html)

### Process

The Melexis.SWCC (SoftWare Competence Center) process has a Guideline for documenting in reStructuredText (RST).
It holds guidelines for using the traceability plugin with naming conventions, templates, etc.
